==> apache-hop-2.9.0-src.tar.gz: apache-hop-2.9.0/plugins/transforms/setvaluefield/src/test/java/org/apache/hop/pipeline/transforms/setvaluefield/SetFieldLoadSaveValidator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hop.pipeline.transforms.setvaluefield;

import java.util.Random;
import java.util.UUID;
import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.hop.pipeline.transforms.loadsave.validator.IFieldLoadSaveValidator;

public class SetFieldLoadSaveValidator implements IFieldLoadSaveValidator<SetField> {
  final Random rand = new Random();

  @Override
  public SetField getTestObject() {
    SetField field = new SetField(UUID.randomUUID().toString(), UUID.randomUUID().toString());

    return field;
  }

  @Override
  public boolean validateTestObject(SetField testObject, Object actual) {
    if (!(actual instanceof SetField)) {
      return false;
    }
    SetField another = (SetField) actual;
    return new EqualsBuilder()
        .append(testObject.getFieldName(), another.getFieldName())
        .append(testObject.getReplaceByField(), another.getReplaceByField())
        .isEquals();
  }
}

==> apache-hop-2.12.0-src.tar.gz: apache-hop-2.12.0/plugins/transforms/setvaluefield/src/test/java/org/apache/hop/pipeline/transforms/setvaluefield/SetFieldLoadSaveValidator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hop.pipeline.transforms.setvaluefield;

import java.util.Random;
import java.util.UUID;
import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.hop.pipeline.transforms.loadsave.validator.IFieldLoadSaveValidator;

public class SetFieldLoadSaveValidator implements IFieldLoadSaveValidator<SetField> {
  final Random rand = new Random();

  @Override
  public SetField getTestObject() {
    return new SetField(UUID.randomUUID().toString(), UUID.randomUUID().toString());
  }

  @Override
  public boolean validateTestObject(SetField testObject, Object actual) {
    if (!(actual instanceof SetField)) {
      return false;
    }
    SetField another = (SetField) actual;
    return new EqualsBuilder()
        .append(testObject.getFieldName(), another.getFieldName())
        .append(testObject.getReplaceByField(), another.getReplaceByField())
        .isEquals();
  }
}
